@@ -1,6 +1,7 @@
 from django.views.generic.base import TemplateView
 from mainapp import models
 
+
 class display_grand_total(TemplateView):
     template_name = 'home.html'
 
@@ -25,10 +26,9 @@ class display_grand_total(TemplateView):
                 for client_stat_entry in client_stat_entries:
                     stat_type = client_stat_entry.type.name
                     stat_value = client_stat_entry.value
-                    if stat_type in global_stats:
-                        global_stats[stat_type] += stat_value
-                    else:
-                        global_stats[stat_type] = stat_value
+                        global_stats[stat_type] = (
+                            global_stats.get(stat_type, 0) + stat_value
+                        )
 
         context['global_stats'] = global_stats
         return context
